@@ -4,6 +4,7 @@ IMPORT_CONSTR = Import.from_full_path('pydantic.constr')
 IMPORT_CONINT = Import.from_full_path('pydantic.conint')
 IMPORT_CONFLOAT = Import.from_full_path('pydantic.confloat')
 IMPORT_CONDECIMAL = Import.from_full_path('pydantic.condecimal')
+IMPORT_CONBYTES = Import.from_full_path('pydantic.conbytes')
 IMPORT_POSITIVE_INT = Import.from_full_path('pydantic.PositiveInt')
 IMPORT_NEGATIVE_INT = Import.from_full_path('pydantic.NegativeInt')
 IMPORT_POSITIVE_FLOAT = Import.from_full_path('pydantic.PositiveFloat')
@@ -20,3 +21,9 @@ IMPORT_IPV4ADDRESS = Import.from_full_path('pydantic.IPv4Address')
 IMPORT_IPV6ADDRESS = Import.from_full_path('pydantic.IPv6Address')
 IMPORT_EXTRA = Import.from_full_path('pydantic.Extra')
 IMPORT_FIELD = Import.from_full_path('pydantic.Field')
+IMPORT_STRICT_INT = Import.from_full_path('pydantic.StrictInt')
+IMPORT_STRICT_FLOAT = Import.from_full_path('pydantic.StrictFloat')
+IMPORT_STRICT_STR = Import.from_full_path('pydantic.StrictStr')
+IMPORT_STRICT_BOOL = Import.from_full_path('pydantic.StrictBool')
+IMPORT_STRICT_BYTES = Import.from_full_path('pydantic.StrictBytes')
+IMPORT_DATACLASS = Import.from_full_path('pydantic.dataclasses.dataclass')
